# `relics`: Resource Extraction Life-cycle IndiCatorS

Import life-cycle assessment indicators to assess the resource extraction
associated to the life-cycle of a product system.

For now limited to metals.

## Impact category

This adds the following indicators to the Brightway project:

* Resource extr., Aluminium (kg)
* Resource extr., Antimony (kg)
* Resource extr., Arsenic (kg)
* Resource extr., Barium (kg)
* Resource extr., Beryllium (kg)
* Resource extr., Boron (kg)
* Resource extr., Cadmium (kg)
* Resource extr., Cerium (kg)
* Resource extr., Chromium (kg)
* Resource extr., Cobalt (kg)
* Resource extr., Copper (kg)
* Resource extr., Dolomite (kg)
* Resource extr., Dysprosium (kg)
* Resource extr., Erbium (kg)
* Resource extr., Europium (kg)
* Resource extr., Gadolinium (kg)
* Resource extr., Gallium (kg)
* Resource extr., Germanium (kg)
* Resource extr., Gold (kg)
* Resource extr., Graphite (kg)
* Resource extr., Hafnium (kg)
* Resource extr., Holmium (kg)
* Resource extr., Indium (kg)
* Resource extr., Iridium (kg)
* Resource extr., Lanthanum (kg)
* Resource extr., Lead (kg)
* Resource extr., Lithium (kg)
* Resource extr., Magnesium (kg)
* Resource extr., Manganese (kg)
* Resource extr., Mercury (kg)
* Resource extr., Molybdenum (kg)
* Resource extr., Neodymium (kg)
* Resource extr., Nickel (kg)
* Resource extr., Niobium (kg)
* Resource extr., Palladium (kg)
* Resource extr., Phosphorus (kg)
* Resource extr., Platinum (kg)
* Resource extr., Potassium (kg)
* Resource extr., Praseodymium (kg)
* Resource extr., Rhenium (kg)
* Resource extr., Rhodium (kg)
* Resource extr., Rubidium (kg)
* Resource extr., Ruthenium (kg)
* Resource extr., Samarium (kg)
* Resource extr., Scandium (kg)
* Resource extr., Selenium (kg)
* Resource extr., Silicon (kg)
* Resource extr., Silver (kg)
* Resource extr., Sodium (kg)
* Resource extr., Spodumene (kg)
* Resource extr., Sulfur (kg)
* Resource extr., Strontium (kg)
* Resource extr., Tantalum (kg)
* Resource extr., Tellurium (kg)
* Resource extr., Terbium (kg)
* Resource extr., Thulium (kg)
* Resource extr., Tin (kg)
* Resource extr., Titanium (kg)
* Resource extr., Tungsten (kg)
* Resource extr., Vanadium (kg)
* Resource extr., Ytterbium (kg)
* Resource extr., Yttrium (kg)
* Resource extr., Zinc (kg)
* Resource extr., Zirconium (kg)


## Usage

In an open Brightway2 project:
```python
from relics import add_relics
add_relics()
```

## Installation

`pip install relics`

or

`conda install -c romainsacchi relics`


## Contributors

* [Alvaro Hahn](https://github.com/alvarojhahn)
* [Romain Sacchi](https://github.com/romainsacchi)


## Contact

* [Alvaro Hahn](mailto:alvaro.hahn-menacho@psi.ch)